@@ -1,19 +1,17 @@
 #!/usr/bin/perl
 #!/usr/bin/speedy
 
-# $Id: tabs-demo.pl,v 1.17 2002/12/02 20:19:37 koos Exp $
+# $Id: tabs-demo.pl,v 1.18 2003/01/16 21:25:35 koos Exp $
 
 use strict;
-use warnings;
 use CGI::Widget::Tabs;
 use CGI::Widget::Tabs::Style;
 
-my @styles = css_styles();
+my @styles = css_styles();  # imported cosmetics
 my $cgi = create_cgi_object();
 exit if ! defined $cgi;
 
-my $style_nr = $cgi->param("style") || 1;
-$style_nr--;  # humans start with 1, lists at 0
+my $current_style = $cgi->param("style") || 1;  # the (currently) selected style sheet
 print <<EOT;
 Content-Type: text/html;
 
@@ -21,12 +19,12 @@ Content-Type: text/html;
 <title>CGI::Widget::Tabs - Demo</title>
 <style type="text/css">
 EOT
-print $styles[$style_nr]->{style};
+print $styles[ $current_style - 1 ]->{style};
 print <<EOT;
 </style>
 </head>
 <body>
-<h1>F1 - Team Simulation - 2002</h1>
+<h1>F1 - Team Simulation - 2003</h1>
 EOT
 
 my $main_tab = CGI::Widget::Tabs->new;  # first set up the main tab
@@ -41,35 +39,40 @@ $main_tab->class("my_tab");  # CSS base style to use
 print "<p>This is the main tab</p>\n";
 $main_tab->display;  # paint the tab
 
-print "<br>";  # I could probably use some CSS bottom margin too.
+print "<br>";  # I could probably take a CSS bottom margin too.
 
 # --- Predefine the possible details tabs.
 # --- Notice how the details tabs are a mix of simple headings and
 # --- OO headings. Various configuration methods are used to illustate
 # --- possible uses.
 # ---
-# --- Usually multiple tabs can be configured much cleaner and more efficient
+# ---
+# --- Usually multiple tabs can be configured much cleaner and more efficient.
 # --- For instance a hash containing a complete menu structure plus options
 # --- can be made in a flash. The reason things look a bit chaotic,
 # --- it is to allow all options being demonstrated.
 
+
 # Set up the details tab. The first few methods are common methods:
 my $details = CGI::Widget::Tabs->new;
 $details->cgi_object($cgi); # access to the outside world
 $details->class("my_tab");  # we'll use the same style sheet as the main tab
 
+
 # --- Differentiate based on the active heading from the main tab
 
 HEADINGS: {
-    # - This tab uses simple headings:
+    # --- "Courses" tab
     ( $main_tab->active eq "Courses" ) && do {
+        # - This tab uses simple headings:
         $details->headings( "Monte Carlo", "Silverstone", "Nurburgring", "Monza" );
         $details->cgi_param("dt");  # _details _tracks
         last HEADINGS;
     };
 
-    # - This tab uses simple headings too, but k/v pairs:
+    # --- "Drivers" tab
     ( $main_tab->active eq "Drivers" ) && do {
+        # - This tab uses simple headings too, but k/v pairs:
         $details->headings( -jpm => "J.P. Montoya",
                             -rs  => "R. Shumacher",
                             -ms  => "M. Shumacher",
@@ -81,15 +84,17 @@ HEADINGS: {
     };
 
 
-    # - This tab goes for the OO approach
+    # --- "Cars" tab
     ( $main_tab->active eq "Cars" ) && do {
+        # - This tab goes for the OO approach
         my $h;
 
         $h = $details->heading;   # add a heading
         $h->text("Ferrari");      # text to display
 
         $h = $details->heading;   # add another heading
-        $h->raw_text("McLaren&nbsp;Mercedes");  # preformatted text to display
+        $h->text("McLaren&nbsp;Mercedes");
+        $h->raw(1);               # do not encode. pass as is.
 
         $h = $details->heading;   # add another heading
         $h->text("BMW Williams"); # text to display...
@@ -97,31 +102,18 @@ HEADINGS: {
 
         $h = $details->heading;   # add another heading
         $h->text("Chrysler");     # |we don't have F1 records on Chrysler
-                                  # |redirect to Chrysler homepage instead
+                                  # |redirect to Chrysler homepage instead.
         $h->url("http://www.chrysler.com");
         $h->key("chr");           # this statement is useless. we don't use
-                                  # the default self refer. URL but a tailored one
+                                  # the default self refer. URL but a tailored one.
 
         $details->cgi_param("dc");  # _details _cars
         last HEADINGS;
     };
 
 
+    # --- "Style sheets" tab
     ( $main_tab->active eq "Style sheets" ) && do {
-
-        # -- We need to know how we got here. So we recreate the
-        # -- query string, modify the style param, and feed it back
-        # -- to the script. The script should then end up in the same
-        # -- state as on the last mouse click.
-        my $query_string = "";
-        # why do we do this by hand ? $tab->active knows this
-        # already. We should be able to access this info.
-        foreach ( $cgi->param() ) {
-            next if ( $_ eq "style" );
-            $query_string .= "$_=".$cgi->param($_)."&";
-        };
-        chop $query_string;
-
         print <<EOT;
 <p>Are you graphically enabled?
 <a style="color:blue" href="mailto:koos_pol\@raketnet.nl?Subject=CGI::Widget::Tabs style sheet">
@@ -131,15 +123,26 @@ Send me</a> your own styles. I will gladly add them to this list!</p>
 <td>Description</td>
 </tr>
 EOT
-       my $style_num = 1 ;
-       foreach my $style ( @styles ) {
-           print "<tr>\n";
-           print "<td>$style_num <a style=\"color:#000000\" href=\"?$query_string&style=$style_num\">".$style->{descr}."</a></td>\n";
-           print "</tr>\n";
-           $style_num++;
-       }
-       print "</table>\n";
-   };
+        # -- We want to stay on this tab, while selecting different
+        # -- style sheets. So we reproduce the URL and only change
+        # -- the style sheet number.
+        my $query_string = "";
+        foreach ( $cgi->param() ) {
+            next if ( $_ eq "style" );
+            $query_string .= "$_=".$cgi->param($_)."&";
+        };
+        chop $query_string;  # remove the last added '&'
+        my $style_num = 1 ;
+        foreach my $style ( @styles ) {
+            print "<tr>\n";
+            print "<td>$style_num <a style=\"color:#000000";
+            print  ";font-weight:bold" if ( $style_num == $current_style );
+            print "\" href=\"?$query_string&style=$style_num\">".$style->{descr}."</a></td>\n";
+            print "</tr>\n";
+            $style_num++;
+        }
+        print "</table>\n";
+    };
 }
 
 
@@ -157,7 +160,7 @@ if ( $main_tab->active ne "Style sheets" ) {
 <br>
 <font color="red">
 WHOAA!  There are two tab headings identified by the same
-value &quot;-ms;&quot;</font>
+key &quot;-ms;&quot;</font>
 EOT
     }
 }
@@ -169,7 +172,7 @@ print "</body>\n</html>";
 # ---------------------------
 sub create_cgi_object {
 # ---------------------------
-    if  ( ( eval {require CGI::Minimal; &CGI::Minimal::reset_globals; $cgi = CGI::Minimal->new} )
+    if  ( ( eval {require CGI::Minimal; CGI::Minimal::reset_globals(); $cgi = CGI::Minimal->new} )
           or
           ( eval {require CGI; $cgi = CGI->new} )
         ) {
